# Generated by Django 4.2.11 on 2024-07-02 12:20

from typing import List

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0049_texttoimagemodelconfig_api_key_and_more"),
        ("database", "0050_alter_processlock_name"),
    ]

    operations: List[str] = []
